@@ -332,7 +332,7 @@ pub fn get_system_user(user: &str) -> EResult<nix::unistd::User> {
     Ok(u)
 }
 
-fn get_system_group(group: &str) -> EResult<nix::unistd::Group> {
+pub fn get_system_group(group: &str) -> EResult<nix::unistd::Group> {
     let g = nix::unistd::Group::from_name(group)
         .map_err(|e| Error::failed(format!("failed to get the system group {}: {}", group, e)))?
         .ok_or_else(|| Error::failed(format!("Failed to locate the system group {}", group)))?;
